*/
/* File......: $macro.prg
*  Author....: cautere@innet.be
*  Date......: $Date... $
*  Revision..: $Revision$
*  Log file..: $Logfile$
*/

/* $DOC$
*  $FUNCNAME$
*     MACROCOMPILE()
*  $CATEGORY$
*     Conversion
*
*  $ONELINER$
*     Eval macro with error capture (and optional alert message).
*     Prevents a runtime error during due to incorrect evaluation of a macro.
*  $SYNTAX$
*
*  $ARGUMENTS$
*
*  $RETURNS$
*    Result of macro extraction, character string on error.
*
*  $EXAMPLES$
*   Use macrocompile(..) (via precompiler)
*  &(macro)  => macrocompile(macro, .T.)  : with alert on error (during debugging)
*  &(macro)  => macrocompile(macro, .F.)  : without alert on error
*  &(macro)  => macrocompile(macro)       : the same as &(macro)
*                                            (no errorcheck: for final version)
*
*
*  $SEEALSO$
*
*  $INCLUDE$
*
*  $END$
*/


FUNCTION MACROCOMPILE(cStr, lMesg)
local bOld
local xResult
if lMesg == NIL
  return &(cStr)
endif
bOld := ErrorBlock({|| break(NIL)})
BEGIN SEQUENCE
 xResult := &(cStr)
 RECOVER
 if lMesg
   if 2 == alert("Error in evaluation of;"+alltrim(cStr),{"Continue", "Stop"})
     errorblock (bOld)
     break
   endif
 endif
 xResult := "**Error**:"+cStr
END SEQUENCE
errorblock (bOld)
return xResult

